pub struct Options {Show 16 fields
pub domain: String,
pub username: String,
pub password: String,
pub ldapfqdn: String,
pub ip: String,
pub port: String,
pub name_server: String,
pub path: String,
pub ldaps: bool,
pub dns_tcp: bool,
pub fqdn_resolver: bool,
pub adcs: bool,
pub old_bloodhound: bool,
pub dc_only: bool,
pub zip: bool,
pub verbose: LevelFilter,
}
domain: String
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.