pub struct Template {Show 18 fields
pub name: String,
pub object_id: String,
pub enrollment_agent: bool,
pub certificate_name_flag: Vec<String>,
pub enrollment_flag: Vec<String>,
pub private_key_flag: Vec<String>,
pub application_policies: Vec<String>,
pub extended_key_usage: Vec<String>,
pub any_purpose: bool,
pub client_authentication: bool,
pub requires_manager_approval: bool,
pub enrollee_supplies_subject: bool,
pub no_security_extension: bool,
pub requires_key_archival: bool,
pub authorized_signatures_required: u64,
pub validity_period: String,
pub renewal_period: String,
pub domain: String,
}
domain: String
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.